/*
	Global function definitions and constants for the AIS Dependability Testbench

	2005. 11. 14.	Zoltan Micskei	created
	2006. 01. 20.	Zoltan Micskei	refactored all functions to return char*
	2006. 11. 13.	Zoltan Micskei	removed functions for types not in AIS.B.01	
*/

#ifndef AIS_TEST_COMMON_DEFINED
#define AIS_TEST_COMMON_DEFINED

#define VERSION_MAJOR 0x01
#define VERSION_MINOR 0x01
#define RELEASE_CODE 'B'

// timeout for tests in seconds
#define TEST_TIMEOUT 5

// in the log file write the headers of the coloumns in the first row
#define WRITE_HEADER SA_TRUE

// stop after this number of calls
#define MAX_NUMBER_OF_CALLS 5000

// where to store log files
#define LOG_FILES_PREFIX "/opt/aisrobustness/typeSpecificTests/bin/log/log_"
#define FINISHED_FILE_NAME "/opt/openais-trunk/exec/finished"

// how much second to wait before starting the calls after the component is started
#define WAIT_BEFORE_START 10

#include "saAis.h"
#include "saAmf.h"
#include "saClm.h"

// AIS types
char* SaNameToString (SaNameT *name);
void setSaNameT (SaNameT *name, char *str);

char* SaDispatchFlagsToString(SaDispatchFlagsT* flag);

char* SaVersionToString(SaVersionT* version);

char* SaAisErrorToString(SaAisErrorT* error);

char* SaSelectionObjectToString(SaSelectionObjectT* selectionObject);

char* SaInvocationToString(SaInvocationT* invocation);

char* SaTimeToString(SaTimeT* t);

char* SaUint8ToString(SaUint8T* i);

char* SaUint32ToString(SaUint32T* i);

char* SaUint64ToString(SaUint64T* i);

char* SaInt32ToString(SaInt32T *i);

char* SaNtfIdentifierToString(SaNtfIdentifierT* identifier);

// AMF types
char* SaAmfHandleToString(SaAmfHandleT* handle);

char* SaAmfCallbacksToString(SaAmfCallbacksT* callBacks);

char* SaAmfHAStateToString(SaAmfHAStateT* haState);

char* SaAmfProtectionGroupChangesToString(SaAmfProtectionGroupChangesT* change);

char* SaAmfProtectionGroupMemberToString(SaAmfProtectionGroupMemberT* pgMember);

char* SaAmfProtectionGroupNotificationToString(SaAmfProtectionGroupNotificationT* notification);

char* SaAmfProtectionGroupNotificationBufferToString(SaAmfProtectionGroupNotificationBufferT* notification);

char* SaAmfRecommendedRecoveryToString(SaAmfRecommendedRecoveryT* recovery);

char* SaAmfHealthcheckKeyToString(SaAmfHealthcheckKeyT* keys);

char* SaAmfHealthcheckInvocationToString(SaAmfHealthcheckInvocationT* invocation);

char* SaAmfPmErrorsToString(SaAmfPmErrorsT* errors);

char* SaAmfPmStopQualifierToString(SaAmfPmStopQualifierT* qualifier);

// CLM types
char* SaClmHandleToString(SaClmHandleT* handle);

char* SaClmCallbacksToString(SaClmCallbacksT* callBacks);

char* SaClmClusterNodeToString(SaClmClusterNodeT* node);

char* SaClmClusterNotificationBufferToString(SaClmClusterNotificationBufferT* notificationBuffer);

char* SaClmNodeIdToString(SaClmNodeIdT* nodeId);

// Logging
void createFileName(char * fileName);
void openLogFile(FILE** logFile, char * fileName, SaBoolT writeHeader);

#endif /* AIS_TEST_COMMON_DEFINED */
