/*
    Summary:
        Type specific generator for AIS types
        
    Description:
        

    Version history:
        Automatically generated by CreateGenerateTypes.exe
*/

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <string.h>

#include "saAis.h"
#include "saClm.h"
#include "saAmf.h"
#include "generateTypes.h"
#include "testCommon.h"

/* ------------------------- Common ----------------------------- */
char * generateLongString(int length)
{
	char* buffer;
	int i = 0;
	int LOW = 1;
	int HIGH = 127;
	
	// do not use a changing seed (like time()), because the tests need to be repeatable
	srand( 5 );
	
	buffer = malloc( length * sizeof(char) );
	if (buffer == NULL)
	{
		perror("Malloc error at generateLongString");
	}
	
	// populate it with random chars
	for (i = 0; i < length; i++)
	{
		buffer[i] = rand() % (HIGH - LOW + 1) + LOW;
	}
	// close the string
	buffer[length - 1] = '\0';
	
	return buffer;	 
}

/* ------------------------- GenericPointer ----------------------------- */
void** generateGenericPointer(int* numberOfGenerated)
{
	static void* values[4];
	*numberOfGenerated = 4;
	
	// do not use a changing seed (like time()), because the tests need to be repeatable
	// srand( 5 );  
	
	// Old approach: use integers, and cast them to pointers
	// problem: produces segmentation faults, which cannot be defended against
	//values[0] = 0;      
	//values[1] = 1;
	//values[2] = -1;
	//values[3] = rand();
	
	values[0] = (void*) NULL; // NULL pointer	
	
	static int a = 5;
	values[1] = (void*) &a;
	
	values[2] = malloc( sizeof(void*) * 10 );
	
	values[3] = malloc( sizeof(void*) * 10 );
	free( values[3] );
	
	return values;
}

// ------------------------- BaseType ---------------------------------
BaseType* generateBaseType(int * numberOfGenerated)
{
    static BaseType values[1];
    *numberOfGenerated = 1;
    
	// 0 - not inicialized
	

    
    return values;
}




// ------------------------- SaVersionT ---------------------------------
SaVersionT* generateSaVersionT(int * numberOfGenerated)
{
    static SaVersionT values[4];
    *numberOfGenerated = 4;
    
	// 0 - not inicialized
	
	// Valid value
	static SaVersionT v1 = {'B', 1, 1};
	values[1] = v1;
	
	// Not valid value (greater than supported)
	static SaVersionT v2 = {'D', 3, 2};
	values[2] = v2;
	
	// Valid value	
	static SaVersionT v3 = { 'A', 1, 1 };
	values[3] = v3;
	

    
    return values;
}


SaVersionT generateValidSaVersionT()
{
    int i;
    SaVersionT* values = generateSaVersionT(&i);

    return values[1];
}

SaVersionT** generatePointerSaVersionT(int * numberOfGenerated)
{
	static SaVersionT** values = NULL;
	
	int number1 = 0; int number2 = 0; int i = 0;
	
	void** genericPointers = generateGenericPointer(&number1);
	SaVersionT* typeSpecificValues = generateSaVersionT(&number2);
	*numberOfGenerated = number1 + number2;
	
	values = (SaVersionT**) malloc( sizeof(SaVersionT**) * (*numberOfGenerated) );
	if ( values == NULL )
	{
		perror("Malloc error in generatePointerSaVersionT\n");
		exit(1);
	}
	
	for (i = 0; i < number1; i++)
	{
		values[i] = (SaVersionT*) genericPointers[i];
	}
	
	for (; i < number1 + number2; i++)
	{
		values[i] = &(typeSpecificValues[ i - number1 ]);
	}
	
	return values;
}

// ------------------------- SaDispatchFlagsT ---------------------------------
SaDispatchFlagsT* generateSaDispatchFlagsT(int * numberOfGenerated)
{
    static SaDispatchFlagsT values[5];
    *numberOfGenerated = 5;
    
	// 0 - not inicialized
	
	// Invalid value
    values[1] = 0;
    
    // SA_DISPATCH_ONE
    values[2] = 1;
    
    // SA_DISPATCH_ALL
    values[3] = 2;
    
    // SA_DISPATCH_BLOCKING
    values[4] = 3;

    
    return values;
}




// ------------------------- SaSelectionObjectT ---------------------------------
SaSelectionObjectT* generateSaSelectionObjectT(int * numberOfGenerated)
{
    static SaSelectionObjectT values[15];
    *numberOfGenerated = 15;
    
	// 0 - not inicialized
	
	// 1. test value 
	values[1] = 1;
	
	// 2. test value 
	values[2] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES;
	
	// 3. test value 
	values[3] = -1;
	
	// 4. test value - random
	srand( 5 ); // do not use a changing seed (like time()), because the tests need to be repeatable
	values[4] = rand();
	
	// 5. test value 
	values[5] = SA_TRACK_CURRENT;
	
	// 6. test value 
	values[6] = SA_TRACK_CHANGES;
	
	// 7. test value 
	values[7] = SA_TRACK_CHANGES_ONLY;
	
	// 8. test value 
	values[8] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 9. test value 
	values[9] = SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 10. test value 
	values[10] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CURRENT;
	
	// 11 test value
	values[11] = pow(2, 8);
	
	// 12 test value
	values[12] = pow(2, 16);
	
	// 13 test value
	values[13] = pow(2, 32);
	
	// 14. test value - wrong file handle
	values[14] = -1;

    
    return values;
}


SaSelectionObjectT** generatePointerSaSelectionObjectT(int * numberOfGenerated)
{
	static SaSelectionObjectT** values = NULL;
	
	int number1 = 0; int number2 = 0; int i = 0;
	
	void** genericPointers = generateGenericPointer(&number1);
	SaSelectionObjectT* typeSpecificValues = generateSaSelectionObjectT(&number2);
	*numberOfGenerated = number1 + number2;
	
	values = (SaSelectionObjectT**) malloc( sizeof(SaSelectionObjectT**) * (*numberOfGenerated) );
	if ( values == NULL )
	{
		perror("Malloc error in generatePointerSaSelectionObjectT\n");
		exit(1);
	}
	
	for (i = 0; i < number1; i++)
	{
		values[i] = (SaSelectionObjectT*) genericPointers[i];
	}
	
	for (; i < number1 + number2; i++)
	{
		values[i] = &(typeSpecificValues[ i - number1 ]);
	}
	
	return values;
}

// ------------------------- SaUint8T ---------------------------------
SaUint8T* generateSaUint8T(int * numberOfGenerated)
{
    static SaUint8T values[11];
    *numberOfGenerated = 11;
    
	// 0 - not inicialized
	
	// 1. test value 
	values[1] = 1;
	
	// 2. test value 
	values[2] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES;
	
	// 3. test value 
	values[3] = -1;
	
	// 4. test value - random
	srand( 5 ); // do not use a changing seed (like time()), because the tests need to be repeatable
	values[4] = rand();
	
	// 5. test value 
	values[5] = SA_TRACK_CURRENT;
	
	// 6. test value 
	values[6] = SA_TRACK_CHANGES;
	
	// 7. test value 
	values[7] = SA_TRACK_CHANGES_ONLY;
	
	// 8. test value 
	values[8] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 9. test value 
	values[9] = SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 10. test value 
	values[10] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CURRENT;
	

    
    return values;
}




// ------------------------- SaUint16T ---------------------------------
SaUint16T* generateSaUint16T(int * numberOfGenerated)
{
    static SaUint16T values[12];
    *numberOfGenerated = 12;
    
	// 0 - not inicialized
	
	// 1. test value 
	values[1] = 1;
	
	// 2. test value 
	values[2] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES;
	
	// 3. test value 
	values[3] = -1;
	
	// 4. test value - random
	srand( 5 ); // do not use a changing seed (like time()), because the tests need to be repeatable
	values[4] = rand();
	
	// 5. test value 
	values[5] = SA_TRACK_CURRENT;
	
	// 6. test value 
	values[6] = SA_TRACK_CHANGES;
	
	// 7. test value 
	values[7] = SA_TRACK_CHANGES_ONLY;
	
	// 8. test value 
	values[8] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 9. test value 
	values[9] = SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 10. test value 
	values[10] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CURRENT;
	
	// 11 test value
	values[11] = pow(2, 8);
	

    
    return values;
}




// ------------------------- SaUint32T ---------------------------------
SaUint32T* generateSaUint32T(int * numberOfGenerated)
{
    static SaUint32T values[13];
    *numberOfGenerated = 13;
    
	// 0 - not inicialized
	
	// 1. test value 
	values[1] = 1;
	
	// 2. test value 
	values[2] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES;
	
	// 3. test value 
	values[3] = -1;
	
	// 4. test value - random
	srand( 5 ); // do not use a changing seed (like time()), because the tests need to be repeatable
	values[4] = rand();
	
	// 5. test value 
	values[5] = SA_TRACK_CURRENT;
	
	// 6. test value 
	values[6] = SA_TRACK_CHANGES;
	
	// 7. test value 
	values[7] = SA_TRACK_CHANGES_ONLY;
	
	// 8. test value 
	values[8] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 9. test value 
	values[9] = SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 10. test value 
	values[10] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CURRENT;
	
	// 11 test value
	values[11] = pow(2, 8);
	
	// 12 test value
	values[12] = pow(2, 16);
	

    
    return values;
}




// ------------------------- SaUint64T ---------------------------------
SaUint64T* generateSaUint64T(int * numberOfGenerated)
{
    static SaUint64T values[14];
    *numberOfGenerated = 14;
    
	// 0 - not inicialized
	
	// 1. test value 
	values[1] = 1;
	
	// 2. test value 
	values[2] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES;
	
	// 3. test value 
	values[3] = -1;
	
	// 4. test value - random
	srand( 5 ); // do not use a changing seed (like time()), because the tests need to be repeatable
	values[4] = rand();
	
	// 5. test value 
	values[5] = SA_TRACK_CURRENT;
	
	// 6. test value 
	values[6] = SA_TRACK_CHANGES;
	
	// 7. test value 
	values[7] = SA_TRACK_CHANGES_ONLY;
	
	// 8. test value 
	values[8] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 9. test value 
	values[9] = SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 10. test value 
	values[10] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CURRENT;
	
	// 11 test value
	values[11] = pow(2, 8);
	
	// 12 test value
	values[12] = pow(2, 16);
	
	// 13 test value
	values[13] = pow(2, 32);
	

    
    return values;
}




// ------------------------- SaInt32T ---------------------------------
SaInt32T* generateSaInt32T(int * numberOfGenerated)
{
    static SaInt32T values[2];
    *numberOfGenerated = 2;
    
	// 0 - not inicialized
	
	// 1 - valid
	values[1] = pow(2, 16) - 1;

    
    return values;
}




// ------------------------- SaInt64T ---------------------------------
SaInt64T* generateSaInt64T(int * numberOfGenerated)
{
    static SaInt64T values[3];
    *numberOfGenerated = 3;
    
	// 0 - not inicialized
	
	// 1 - valid
	values[1] = pow(2, 16) - 1;
	// 2 test value
	values[2] = pow(2, 32) - 1;
	

    
    return values;
}




// ------------------------- SaTimeT ---------------------------------
SaTimeT* generateSaTimeT(int * numberOfGenerated)
{
    static SaTimeT values[4];
    *numberOfGenerated = 4;
    
	// 0 - not inicialized
	
	// 1 - valid
	values[1] = pow(2, 16) - 1;
	// 2 test value
	values[2] = pow(2, 32) - 1;
	
	// 3 value - unknown time
	values[3] = SA_TIME_UNKNOWN;
	

    
    return values;
}




// ------------------------- SaInvocationT ---------------------------------
SaInvocationT* generateSaInvocationT(int * numberOfGenerated)
{
    static SaInvocationT values[15];
    *numberOfGenerated = 15;
    
	// 0 - not inicialized
	
	// 1. test value 
	values[1] = 1;
	
	// 2. test value 
	values[2] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES;
	
	// 3. test value 
	values[3] = -1;
	
	// 4. test value - random
	srand( 5 ); // do not use a changing seed (like time()), because the tests need to be repeatable
	values[4] = rand();
	
	// 5. test value 
	values[5] = SA_TRACK_CURRENT;
	
	// 6. test value 
	values[6] = SA_TRACK_CHANGES;
	
	// 7. test value 
	values[7] = SA_TRACK_CHANGES_ONLY;
	
	// 8. test value 
	values[8] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 9. test value 
	values[9] = SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 10. test value 
	values[10] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CURRENT;
	
	// 11 test value
	values[11] = pow(2, 8);
	
	// 12 test value
	values[12] = pow(2, 16);
	
	// 13 test value
	values[13] = pow(2, 32);
	
	// 14 - placeholder value
	//TODO should include here a valid invocation
	//however, an valid invocation can only be obtained, if AMF calls the component
	//through a callback. How can be force a callback?
	

    
    return values;
}




// ------------------------- SaAisErrorT ---------------------------------
SaAisErrorT* generateSaAisErrorT(int * numberOfGenerated)
{
    static SaAisErrorT values[4];
    *numberOfGenerated = 4;
    
	// 0 - not inicialized
	
	// 1 - invalid value
	values[1] = -1;
	//2 - valid value meaning an error
	values[2] = SA_AIS_ERR_TRY_AGAIN;
	// 3
	values[3] = SA_AIS_OK;
	

    
    return values;
}




// ------------------------- SaNameT ---------------------------------
SaNameT* generateSaNameT(int * numberOfGenerated)
{
    static SaNameT values[6];
    *numberOfGenerated = 6;
    
	// 0 - not inicialized
	
	// 1 - not valid length
	values[1].length = strlen( "string1" ) + 20;
	memcpy( values[1].value, "string1", values[1].length );
	
	// 2 - not defined component name
	values[2].length = strlen( "safComp=UnknownComponent" );
	memcpy( values[2].value, "safComp=UnknownComponent", values[2].length );
	
	// 3 - component name belonging to this process		
	SaAmfHandleT handle = generateValidSaAmfHandleT();	
	
	SaAisErrorT result = saAmfComponentNameGet( handle, &(values[3]) );
	printf( "LOG>SaAmfComponentNameGet result in valid generateSaNameT: %s, name: %s\n", 
		SaAisErrorToString(&result), SaNameToString(&(values[3])) );
	
	result = saAmfComponentRegister(handle, &(values[3]), NULL );
	printf( "LOG>SaAmfComponentRegister result in valid generateSaNameT: %s\n", SaAisErrorToString(&result) );
	
	// 4 - name not specified in LDAP DN format
	values[4].length = strlen( "aisRobustnessComp" );
	memcpy( values[4].value, "aisRobustnessComp", values[4].length );
	
	// 5 - service unit name
	values[5].length = strlen( "safSu=aisRobustnessSU" );
	memcpy( values[5].value, "safSu=aisRobustnessSU", values[5].length );
	

    
    return values;
}


SaNameT generateValidSaNameT()
{
    int i;
    SaNameT* values = generateSaNameT(&i);

    return values[1];
}

SaNameT** generatePointerSaNameT(int * numberOfGenerated)
{
	static SaNameT** values = NULL;
	
	int number1 = 0; int number2 = 0; int i = 0;
	
	void** genericPointers = generateGenericPointer(&number1);
	SaNameT* typeSpecificValues = generateSaNameT(&number2);
	*numberOfGenerated = number1 + number2;
	
	values = (SaNameT**) malloc( sizeof(SaNameT**) * (*numberOfGenerated) );
	if ( values == NULL )
	{
		perror("Malloc error in generatePointerSaNameT\n");
		exit(1);
	}
	
	for (i = 0; i < number1; i++)
	{
		values[i] = (SaNameT*) genericPointers[i];
	}
	
	for (; i < number1 + number2; i++)
	{
		values[i] = &(typeSpecificValues[ i - number1 ]);
	}
	
	return values;
}

// ------------------------- StringStructure ---------------------------------
StringStructure* generateStringStructure(int * numberOfGenerated)
{
    static StringStructure values[2];
    *numberOfGenerated = 2;
    
	// 0 - not inicialized
	
	// 1 - not valid length
	values[1].length = strlen( "string1" ) + 20;
	memcpy( values[1].value, "string1", values[1].length );
	

    
    return values;
}


StringStructure** generatePointerStringStructure(int * numberOfGenerated)
{
	static StringStructure** values = NULL;
	
	int number1 = 0; int number2 = 0; int i = 0;
	
	void** genericPointers = generateGenericPointer(&number1);
	StringStructure* typeSpecificValues = generateStringStructure(&number2);
	*numberOfGenerated = number1 + number2;
	
	values = (StringStructure**) malloc( sizeof(StringStructure**) * (*numberOfGenerated) );
	if ( values == NULL )
	{
		perror("Malloc error in generatePointerStringStructure\n");
		exit(1);
	}
	
	for (i = 0; i < number1; i++)
	{
		values[i] = (StringStructure*) genericPointers[i];
	}
	
	for (; i < number1 + number2; i++)
	{
		values[i] = &(typeSpecificValues[ i - number1 ]);
	}
	
	return values;
}

// ------------------------- SaNtfIdentifierT ---------------------------------
SaNtfIdentifierT* generateSaNtfIdentifierT(int * numberOfGenerated)
{
    static SaNtfIdentifierT values[15];
    *numberOfGenerated = 15;
    
	// 0 - not inicialized
	
	// 1. test value 
	values[1] = 1;
	
	// 2. test value 
	values[2] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES;
	
	// 3. test value 
	values[3] = -1;
	
	// 4. test value - random
	srand( 5 ); // do not use a changing seed (like time()), because the tests need to be repeatable
	values[4] = rand();
	
	// 5. test value 
	values[5] = SA_TRACK_CURRENT;
	
	// 6. test value 
	values[6] = SA_TRACK_CHANGES;
	
	// 7. test value 
	values[7] = SA_TRACK_CHANGES_ONLY;
	
	// 8. test value 
	values[8] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 9. test value 
	values[9] = SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 10. test value 
	values[10] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CURRENT;
	
	// 11 test value
	values[11] = pow(2, 8);
	
	// 12 test value
	values[12] = pow(2, 16);
	
	// 13 test value
	values[13] = pow(2, 32);
	
	// 14 - placeholder


    
    return values;
}




// ------------------------- SaAmfHandleT ---------------------------------
SaAmfHandleT* generateSaAmfHandleT(int * numberOfGenerated)
{
    static SaAmfHandleT values[4];
    *numberOfGenerated = 4;
    
	// 0 - not inicialized
	
	// 1 not valid handle
	values[1] = -1;
	
	// correctly inicialized handle with no callbacks
	SaVersionT validVersion2 = {'B', 1, 1}; // OpenAIS supports for AMF only AIS B.1.1
	SaAmfCallbacksT callBacks2;
	SaAisErrorT result2 = saAmfInitialize( &values[2], &callBacks2, &validVersion2 );
	printf("LOG>generateSaAmfHandleT value 2: result: %s\n", SaAisErrorToString(&result2) );
	
	// correctly inicialized handle with callbacks
	SaVersionT validVersion3 = {'B', 1, 1}; // OpenAIS supports for AMF only AIS B.1.1
	SaAmfCallbacksT callBacks3 = generateValidSaAmfCallbacksT();
	SaAisErrorT result3 = saAmfInitialize( &values[3], &callBacks3, &validVersion3 );
	printf("LOG>generateSaAmfHandleT value 2: result: %s\n", SaAisErrorToString(&result3) );
	

    
    return values;
}


SaAmfHandleT generateValidSaAmfHandleT()
{
    int i;
    SaAmfHandleT* values = generateSaAmfHandleT(&i);

    return values[3];
}

SaAmfHandleT** generatePointerSaAmfHandleT(int * numberOfGenerated)
{
	static SaAmfHandleT** values = NULL;
	
	int number1 = 0; int number2 = 0; int i = 0;
	
	void** genericPointers = generateGenericPointer(&number1);
	SaAmfHandleT* typeSpecificValues = generateSaAmfHandleT(&number2);
	*numberOfGenerated = number1 + number2;
	
	values = (SaAmfHandleT**) malloc( sizeof(SaAmfHandleT**) * (*numberOfGenerated) );
	if ( values == NULL )
	{
		perror("Malloc error in generatePointerSaAmfHandleT\n");
		exit(1);
	}
	
	for (i = 0; i < number1; i++)
	{
		values[i] = (SaAmfHandleT*) genericPointers[i];
	}
	
	for (; i < number1 + number2; i++)
	{
		values[i] = &(typeSpecificValues[ i - number1 ]);
	}
	
	return values;
}

void amfHealthcheckCallback ( SaInvocationT invocation, const SaNameT *compName, SaAmfHealthcheckKeyT *healthcheckKey)
{
	printf("amfHealthcheckCallback called\n");
	return;
}

void amfComponentTerminateCallback ( SaInvocationT invocation,const SaNameT *compName)
{
	printf("amfComponentTerminateCallback called\n");
	return;	
}

//BUG openais uses the last parameter as a pointer
void amfCSISetCallback (SaInvocationT invocation,const SaNameT *compName, SaAmfHAStateT haState,SaAmfCSIDescriptorT *csiDescriptor)                
{
	printf("amfCSISetCallback called\n");
	return;
}
			
void amfCSIRemoveCallback (SaInvocationT invocation,const SaNameT *compName,const SaNameT *csiName,const SaAmfCSIFlagsT csiFlags)
{
	printf("amfCSIRemoveCallback called\n");
	return;
}

//BUG openais uses SaAmfProtectionGroupNotificationT instead of SaAmfProtectionGroupNotificationBufferT
void amfProtectionGroupTrackCallback (const SaNameT *csiName,SaAmfProtectionGroupNotificationT *notificationBuffer,
	SaUint32T numberOfMembers,SaAisErrorT error)
{
	printf("amfProtectionGroupTrackCallback called\n");
	return;
}

void amfProxiedComponentInstantiateCallback (SaInvocationT invocation,const SaNameT *proxiedCompName)
{
	printf("amfProxiedComponentInstantiateCallback called\n");
	return;
}

void amfProxiedComponentCleanupCallback (SaInvocationT invocation,const SaNameT *proxiedCompName)
{
	printf("amfProxiedComponentCleanupCallback called\n");
	return;
}

// ------------------------- SaAmfCallbacksT ---------------------------------
SaAmfCallbacksT* generateSaAmfCallbacksT(int * numberOfGenerated)
{
    static SaAmfCallbacksT values[3];
    *numberOfGenerated = 3;
    
	// 0 - not inicialized
	
	// Valid value: all callback null
    (values[1]).saAmfHealthcheckCallback  = NULL;
    (values[1]).saAmfComponentTerminateCallback = NULL;
    (values[1]).saAmfCSISetCallback = NULL;
    (values[1]).saAmfCSIRemoveCallback = NULL;
    (values[1]).saAmfProtectionGroupTrackCallback = NULL;
    (values[1]).saAmfExternalComponentInstantiateCallback = NULL;
    (values[1]).saAmfExternalComponentCleanupCallback = NULL;
    
	// Valid value: all callbacks set to a valid function
    (values[2]).saAmfHealthcheckCallback  = amfHealthcheckCallback;
    (values[2]).saAmfComponentTerminateCallback = amfComponentTerminateCallback;
    (values[2]).saAmfCSISetCallback = amfCSISetCallback;
    (values[2]).saAmfCSIRemoveCallback = amfCSIRemoveCallback;
    (values[2]).saAmfProtectionGroupTrackCallback = amfProtectionGroupTrackCallback;
    (values[2]).saAmfExternalComponentInstantiateCallback = amfProxiedComponentInstantiateCallback;
    (values[2]).saAmfExternalComponentCleanupCallback = amfProxiedComponentCleanupCallback;



    
    return values;
}


SaAmfCallbacksT generateValidSaAmfCallbacksT()
{
    int i;
    SaAmfCallbacksT* values = generateSaAmfCallbacksT(&i);

    return values[2];
}

SaAmfCallbacksT** generatePointerSaAmfCallbacksT(int * numberOfGenerated)
{
	static SaAmfCallbacksT** values = NULL;
	
	int number1 = 0; int number2 = 0; int i = 0;
	
	void** genericPointers = generateGenericPointer(&number1);
	SaAmfCallbacksT* typeSpecificValues = generateSaAmfCallbacksT(&number2);
	*numberOfGenerated = number1 + number2;
	
	values = (SaAmfCallbacksT**) malloc( sizeof(SaAmfCallbacksT**) * (*numberOfGenerated) );
	if ( values == NULL )
	{
		perror("Malloc error in generatePointerSaAmfCallbacksT\n");
		exit(1);
	}
	
	for (i = 0; i < number1; i++)
	{
		values[i] = (SaAmfCallbacksT*) genericPointers[i];
	}
	
	for (; i < number1 + number2; i++)
	{
		values[i] = &(typeSpecificValues[ i - number1 ]);
	}
	
	return values;
}

// ------------------------- SaAmfHAStateT ---------------------------------
SaAmfHAStateT* generateSaAmfHAStateT(int * numberOfGenerated)
{
    static SaAmfHAStateT values[5];
    *numberOfGenerated = 5;
    
	// 0 - not inicialized
	
	// 1 not valid
	values[1] = -1;
	
	// 2 
	values[2] = SA_AMF_HA_ACTIVE;
	
	// 3 
	values[3] = SA_AMF_HA_STANDBY;
	
	// 4 
	values[4] = SA_AMF_HA_QUIESCED;
	

    
    return values;
}


SaAmfHAStateT** generatePointerSaAmfHAStateT(int * numberOfGenerated)
{
	static SaAmfHAStateT** values = NULL;
	
	int number1 = 0; int number2 = 0; int i = 0;
	
	void** genericPointers = generateGenericPointer(&number1);
	SaAmfHAStateT* typeSpecificValues = generateSaAmfHAStateT(&number2);
	*numberOfGenerated = number1 + number2;
	
	values = (SaAmfHAStateT**) malloc( sizeof(SaAmfHAStateT**) * (*numberOfGenerated) );
	if ( values == NULL )
	{
		perror("Malloc error in generatePointerSaAmfHAStateT\n");
		exit(1);
	}
	
	for (i = 0; i < number1; i++)
	{
		values[i] = (SaAmfHAStateT*) genericPointers[i];
	}
	
	for (; i < number1 + number2; i++)
	{
		values[i] = &(typeSpecificValues[ i - number1 ]);
	}
	
	return values;
}

// ------------------------- SaAmfProtectionGroupMemberT ---------------------------------
SaAmfProtectionGroupMemberT* generateSaAmfProtectionGroupMemberT(int * numberOfGenerated)
{
    static SaAmfProtectionGroupMemberT values[5];
    *numberOfGenerated = 5;
    
	// 0 - not inicialized
	
	// 1 - valid member
	values[1].compName = generateValidSaNameT();
	values[1].haState = SA_AMF_HA_ACTIVE;
	values[1].rank = 1;
	
	// 2 - not valid compName
	SaNameT notValidName;
	notValidName.length = strlen("notValid");
	memcpy( notValidName.value, "notValid", strlen("notValid") );
	
	values[2].compName = notValidName;
	// 3 - invalid haState
	values[3].compName = generateValidSaNameT();
	values[3].haState = -1;
	values[3].rank = 1;
	// 4 - invalid rank
	values[4].compName = generateValidSaNameT();
	values[4].haState = SA_AMF_HA_ACTIVE;
	values[4].rank = -1;

    
    return values;
}


SaAmfProtectionGroupMemberT generateValidSaAmfProtectionGroupMemberT()
{
    int i;
    SaAmfProtectionGroupMemberT* values = generateSaAmfProtectionGroupMemberT(&i);

    return values[1];
}

SaAmfProtectionGroupMemberT** generatePointerSaAmfProtectionGroupMemberT(int * numberOfGenerated)
{
	static SaAmfProtectionGroupMemberT** values = NULL;
	
	int number1 = 0; int number2 = 0; int i = 0;
	
	void** genericPointers = generateGenericPointer(&number1);
	SaAmfProtectionGroupMemberT* typeSpecificValues = generateSaAmfProtectionGroupMemberT(&number2);
	*numberOfGenerated = number1 + number2;
	
	values = (SaAmfProtectionGroupMemberT**) malloc( sizeof(SaAmfProtectionGroupMemberT**) * (*numberOfGenerated) );
	if ( values == NULL )
	{
		perror("Malloc error in generatePointerSaAmfProtectionGroupMemberT\n");
		exit(1);
	}
	
	for (i = 0; i < number1; i++)
	{
		values[i] = (SaAmfProtectionGroupMemberT*) genericPointers[i];
	}
	
	for (; i < number1 + number2; i++)
	{
		values[i] = &(typeSpecificValues[ i - number1 ]);
	}
	
	return values;
}

// ------------------------- SaAmfProtectionGroupNotificationT ---------------------------------
SaAmfProtectionGroupNotificationT* generateSaAmfProtectionGroupNotificationT(int * numberOfGenerated)
{
    static SaAmfProtectionGroupNotificationT values[2];
    *numberOfGenerated = 2;
    
	// 0 - not inicialized
	
	// 1
	values[1].member = generateValidSaAmfProtectionGroupMemberT();
	values[1].change = SA_AMF_PROTECTION_GROUP_NO_CHANGE;
	

    
    return values;
}


SaAmfProtectionGroupNotificationT generateValidSaAmfProtectionGroupNotificationT()
{
    int i;
    SaAmfProtectionGroupNotificationT* values = generateSaAmfProtectionGroupNotificationT(&i);

    return values[1];
}

SaAmfProtectionGroupNotificationT** generatePointerSaAmfProtectionGroupNotificationT(int * numberOfGenerated)
{
	static SaAmfProtectionGroupNotificationT** values = NULL;
	
	int number1 = 0; int number2 = 0; int i = 0;
	
	void** genericPointers = generateGenericPointer(&number1);
	SaAmfProtectionGroupNotificationT* typeSpecificValues = generateSaAmfProtectionGroupNotificationT(&number2);
	*numberOfGenerated = number1 + number2;
	
	values = (SaAmfProtectionGroupNotificationT**) malloc( sizeof(SaAmfProtectionGroupNotificationT**) * (*numberOfGenerated) );
	if ( values == NULL )
	{
		perror("Malloc error in generatePointerSaAmfProtectionGroupNotificationT\n");
		exit(1);
	}
	
	for (i = 0; i < number1; i++)
	{
		values[i] = (SaAmfProtectionGroupNotificationT*) genericPointers[i];
	}
	
	for (; i < number1 + number2; i++)
	{
		values[i] = &(typeSpecificValues[ i - number1 ]);
	}
	
	return values;
}

// ------------------------- SaAmfProtectionGroupNotificationBufferT ---------------------------------
SaAmfProtectionGroupNotificationBufferT* generateSaAmfProtectionGroupNotificationBufferT(int * numberOfGenerated)
{
    static SaAmfProtectionGroupNotificationBufferT values[4];
    *numberOfGenerated = 4;
    
	// 0 - not inicialized
	
	// 1 - valid, zero changes
	values[1].numberOfItems = 0;
	values[1].notification = NULL;
	//BUG in openais this member is misspelled: notificaton
	// 2 - one valid value
	int i;
	
	values[2].numberOfItems = 1;
	//TODO number of the valid value is hardcoded
	values[2].notification = generatePointerSaAmfProtectionGroupNotificationT(&i)[5];
	// 3 - numberOfItems not valid
	values[3].numberOfItems = 2;	
	//TODO number of the valid value is hardcoded
	values[3].notification = generatePointerSaAmfProtectionGroupNotificationT(&i)[5];
	

    
    return values;
}


SaAmfProtectionGroupNotificationBufferT** generatePointerSaAmfProtectionGroupNotificationBufferT(int * numberOfGenerated)
{
	static SaAmfProtectionGroupNotificationBufferT** values = NULL;
	
	int number1 = 0; int number2 = 0; int i = 0;
	
	void** genericPointers = generateGenericPointer(&number1);
	SaAmfProtectionGroupNotificationBufferT* typeSpecificValues = generateSaAmfProtectionGroupNotificationBufferT(&number2);
	*numberOfGenerated = number1 + number2;
	
	values = (SaAmfProtectionGroupNotificationBufferT**) malloc( sizeof(SaAmfProtectionGroupNotificationBufferT**) * (*numberOfGenerated) );
	if ( values == NULL )
	{
		perror("Malloc error in generatePointerSaAmfProtectionGroupNotificationBufferT\n");
		exit(1);
	}
	
	for (i = 0; i < number1; i++)
	{
		values[i] = (SaAmfProtectionGroupNotificationBufferT*) genericPointers[i];
	}
	
	for (; i < number1 + number2; i++)
	{
		values[i] = &(typeSpecificValues[ i - number1 ]);
	}
	
	return values;
}

// ------------------------- SaAmfRecommendedRecoveryT ---------------------------------
SaAmfRecommendedRecoveryT* generateSaAmfRecommendedRecoveryT(int * numberOfGenerated)
{
    static SaAmfRecommendedRecoveryT values[3];
    *numberOfGenerated = 3;
    
	// 0 - not inicialized
	
	// 1 valid value
	values[1] = SA_AMF_COMPONENT_FAILOVER;
	// 2 - invalid value
	values[2] = 0;

    
    return values;
}




// ------------------------- SaAmfHealthcheckKeyT ---------------------------------
SaAmfHealthcheckKeyT* generateSaAmfHealthcheckKeyT(int * numberOfGenerated)
{
    static SaAmfHealthcheckKeyT values[5];
    *numberOfGenerated = 5;
    
	// 0 - not inicialized
	
	// 1 - valid value: key defined in the config file
	values[1].keyLen = strlen("key1");
	memcpy(values[1].key, "key1", strlen("key1"));
	
	// 2 - invalid key, not defined in the configuration
	values[2].keyLen = strlen("key2");
	memcpy(values[2].key, "key2", strlen("key2"));
	// 3 - invalid keyLen
	values[3].keyLen = 10;
	memcpy(values[3].key, "key1", strlen("key1"));
	
	// 4 - too greate keyLen
	values[4].keyLen = SA_AMF_HEALTHCHECK_KEY_MAX + 10;

    
    return values;
}


SaAmfHealthcheckKeyT** generatePointerSaAmfHealthcheckKeyT(int * numberOfGenerated)
{
	static SaAmfHealthcheckKeyT** values = NULL;
	
	int number1 = 0; int number2 = 0; int i = 0;
	
	void** genericPointers = generateGenericPointer(&number1);
	SaAmfHealthcheckKeyT* typeSpecificValues = generateSaAmfHealthcheckKeyT(&number2);
	*numberOfGenerated = number1 + number2;
	
	values = (SaAmfHealthcheckKeyT**) malloc( sizeof(SaAmfHealthcheckKeyT**) * (*numberOfGenerated) );
	if ( values == NULL )
	{
		perror("Malloc error in generatePointerSaAmfHealthcheckKeyT\n");
		exit(1);
	}
	
	for (i = 0; i < number1; i++)
	{
		values[i] = (SaAmfHealthcheckKeyT*) genericPointers[i];
	}
	
	for (; i < number1 + number2; i++)
	{
		values[i] = &(typeSpecificValues[ i - number1 ]);
	}
	
	return values;
}

// ------------------------- SaAmfHealthcheckInvocationT ---------------------------------
SaAmfHealthcheckInvocationT* generateSaAmfHealthcheckInvocationT(int * numberOfGenerated)
{
    static SaAmfHealthcheckInvocationT values[3];
    *numberOfGenerated = 3;
    
	// 0 - not inicialized
	
	// 1 - valid value
	values[1] = SA_AMF_HEALTHCHECK_AMF_INVOKED;
	
	// 2 - invalid value
	values[2] = 0;
	

    
    return values;
}




// ------------------------- SaAmfPmErrorsT ---------------------------------
SaAmfPmErrorsT* generateSaAmfPmErrorsT(int * numberOfGenerated)
{
    static SaAmfPmErrorsT values[15];
    *numberOfGenerated = 15;
    
	// 0 - not inicialized
	
	// 1. test value 
	values[1] = 1;
	
	// 2. test value 
	values[2] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES;
	
	// 3. test value 
	values[3] = -1;
	
	// 4. test value - random
	srand( 5 ); // do not use a changing seed (like time()), because the tests need to be repeatable
	values[4] = rand();
	
	// 5. test value 
	values[5] = SA_TRACK_CURRENT;
	
	// 6. test value 
	values[6] = SA_TRACK_CHANGES;
	
	// 7. test value 
	values[7] = SA_TRACK_CHANGES_ONLY;
	
	// 8. test value 
	values[8] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 9. test value 
	values[9] = SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 10. test value 
	values[10] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CURRENT;
	
	// 11 test value
	values[11] = pow(2, 8);
	
	// 12 test value
	values[12] = pow(2, 16);
	
	// 13 - valid value
	values[13] = SA_AMF_PM_ZERO_EXIT;
	
	// 14 - invalid value
	values[14] = -1;

    
    return values;
}




// ------------------------- SaAmfPmStopQualifierT ---------------------------------
SaAmfPmStopQualifierT* generateSaAmfPmStopQualifierT(int * numberOfGenerated)
{
    static SaAmfPmStopQualifierT values[3];
    *numberOfGenerated = 3;
    
	// 0 - not inicialized
	
	// 1 - valid value
	values[1] = SA_AMF_PM_PROC;
	
	// 2 - invalid value
	values[2] = 0;

    
    return values;
}




void clmClusterTrackCallback( SaClmClusterNotificationBufferT *notificationBuffer, SaUint32T numberOfMembers, SaAisErrorT error) 
{
    printf( "ClmClusterTrackCallback called\n" );
    return;
}

void clmClusterNodeGetCallback(SaInvocationT invocation, SaClmClusterNodeT *clusterNode, SaAisErrorT error)
{
	printf( "clmClusterNodeGetCallback called\n" );
	return;
}
// ------------------------- SaClmCallbacksT ---------------------------------
SaClmCallbacksT* generateSaClmCallbacksT(int * numberOfGenerated)
{
    static SaClmCallbacksT values[3];
    *numberOfGenerated = 3;
    
	// 0 - not inicialized
	
	// Valid value: both callback null
    (values[1]).saClmClusterNodeGetCallback  = NULL;
    (values[1]).saClmClusterTrackCallback = NULL;
    
    // Valid value: both callback set
    (values[2]).saClmClusterNodeGetCallback = (SaClmClusterNodeGetCallbackT) clmClusterNodeGetCallback;
    (values[2]).saClmClusterTrackCallback = (SaClmClusterTrackCallbackT) clmClusterTrackCallback;

    
    return values;
}


SaClmCallbacksT generateValidSaClmCallbacksT()
{
    int i;
    SaClmCallbacksT* values = generateSaClmCallbacksT(&i);

    return values[2];
}

SaClmCallbacksT** generatePointerSaClmCallbacksT(int * numberOfGenerated)
{
	static SaClmCallbacksT** values = NULL;
	
	int number1 = 0; int number2 = 0; int i = 0;
	
	void** genericPointers = generateGenericPointer(&number1);
	SaClmCallbacksT* typeSpecificValues = generateSaClmCallbacksT(&number2);
	*numberOfGenerated = number1 + number2;
	
	values = (SaClmCallbacksT**) malloc( sizeof(SaClmCallbacksT**) * (*numberOfGenerated) );
	if ( values == NULL )
	{
		perror("Malloc error in generatePointerSaClmCallbacksT\n");
		exit(1);
	}
	
	for (i = 0; i < number1; i++)
	{
		values[i] = (SaClmCallbacksT*) genericPointers[i];
	}
	
	for (; i < number1 + number2; i++)
	{
		values[i] = &(typeSpecificValues[ i - number1 ]);
	}
	
	return values;
}

// ------------------------- SaClmClusterChangesT ---------------------------------
SaClmClusterChangesT* generateSaClmClusterChangesT(int * numberOfGenerated)
{
    static SaClmClusterChangesT values[6];
    *numberOfGenerated = 6;
    
	// 0 - not inicialized
	
	// 1 test value - not valid
	values[1] = 0;
	
	// 2 test value
	values[2] = SA_CLM_NODE_NO_CHANGE;
	
	// 3 test value
	values[3] = SA_CLM_NODE_JOINED;

	// 4 test value
	values[4] = SA_CLM_NODE_LEFT;

	// 5 test value
	values[5] = SA_CLM_NODE_RECONFIGURED;


    
    return values;
}




// ------------------------- SaClmClusterNodeT ---------------------------------
SaClmClusterNodeT* generateSaClmClusterNodeT(int * numberOfGenerated)
{
    static SaClmClusterNodeT values[2];
    *numberOfGenerated = 2;
    
	// 0 - not inicialized
	
	// 1 test value
	SaAisErrorT result;
	result = saClmClusterNodeGet( generateValidSaClmHandleT(), SA_CLM_LOCAL_NODE_ID, 1000, &(values[1]) );
	

    
    return values;
}


SaClmClusterNodeT generateValidSaClmClusterNodeT()
{
    int i;
    SaClmClusterNodeT* values = generateSaClmClusterNodeT(&i);

    return values[1];
}

SaClmClusterNodeT** generatePointerSaClmClusterNodeT(int * numberOfGenerated)
{
	static SaClmClusterNodeT** values = NULL;
	
	int number1 = 0; int number2 = 0; int i = 0;
	
	void** genericPointers = generateGenericPointer(&number1);
	SaClmClusterNodeT* typeSpecificValues = generateSaClmClusterNodeT(&number2);
	*numberOfGenerated = number1 + number2;
	
	values = (SaClmClusterNodeT**) malloc( sizeof(SaClmClusterNodeT**) * (*numberOfGenerated) );
	if ( values == NULL )
	{
		perror("Malloc error in generatePointerSaClmClusterNodeT\n");
		exit(1);
	}
	
	for (i = 0; i < number1; i++)
	{
		values[i] = (SaClmClusterNodeT*) genericPointers[i];
	}
	
	for (; i < number1 + number2; i++)
	{
		values[i] = &(typeSpecificValues[ i - number1 ]);
	}
	
	return values;
}

// ------------------------- SaClmClusterNotificationBufferT ---------------------------------
SaClmClusterNotificationBufferT* generateSaClmClusterNotificationBufferT(int * numberOfGenerated)
{
    static SaClmClusterNotificationBufferT values[3];
    *numberOfGenerated = 3;
    
	// 0 - not inicialized
	
	// 1
	values[1].viewNumber = 0;
	values[1].numberOfItems = 2;
	values[1].notification = NULL;	
	
	// 2
	SaClmClusterNotificationT * notification = malloc( sizeof(SaClmClusterNotificationT) );
	if ( notification == NULL )
	{
		perror("Malloc error in generateSaClmClusterNotificationBufferT\n");
		exit(1);
	}
	notification->clusterNode = generateValidSaClmClusterNodeT();
	notification->clusterChange = SA_CLM_NODE_NO_CHANGE;
	
	values[2].viewNumber = 0;
	values[2].numberOfItems = 1;
	values[2].notification = notification;
	

    
    return values;
}


SaClmClusterNotificationBufferT** generatePointerSaClmClusterNotificationBufferT(int * numberOfGenerated)
{
	static SaClmClusterNotificationBufferT** values = NULL;
	
	int number1 = 0; int number2 = 0; int i = 0;
	
	void** genericPointers = generateGenericPointer(&number1);
	SaClmClusterNotificationBufferT* typeSpecificValues = generateSaClmClusterNotificationBufferT(&number2);
	*numberOfGenerated = number1 + number2;
	
	values = (SaClmClusterNotificationBufferT**) malloc( sizeof(SaClmClusterNotificationBufferT**) * (*numberOfGenerated) );
	if ( values == NULL )
	{
		perror("Malloc error in generatePointerSaClmClusterNotificationBufferT\n");
		exit(1);
	}
	
	for (i = 0; i < number1; i++)
	{
		values[i] = (SaClmClusterNotificationBufferT*) genericPointers[i];
	}
	
	for (; i < number1 + number2; i++)
	{
		values[i] = &(typeSpecificValues[ i - number1 ]);
	}
	
	return values;
}

// ------------------------- SaClmHandleT ---------------------------------
SaClmHandleT* generateSaClmHandleT(int * numberOfGenerated)
{
    static SaClmHandleT values[5];
    *numberOfGenerated = 5;
    
	// 0 - not inicialized
	
	// 1 not valid handle
	values[1] = -1;
	
	// correctly inicialized handle with no callbacks
	SaVersionT validVersion = generateValidSaVersionT();
	SaAisErrorT result = saClmInitialize( &values[2], NULL, &validVersion );
	printf("LOG>generateSaClmHandleT value 2: result: %s\n", SaAisErrorToString(&result) );

	// finalized handle
	result = saClmInitialize( &values[3], NULL, &validVersion );
	//printf("LOG>generateSaClmHandleT value 3: result: %s\n", SaErrorToString(&result) );    
	result = saClmFinalize( values[3] );
	//printf("LOG>generateSaClmHandleT value 3 finalize: result: %s\n", SaErrorToString(&result) );
	
	// correctly inicialized handle with callbacks	
	SaClmCallbacksT callbacks4 = generateValidSaClmCallbacksT();
	result = saClmInitialize( &values[4], &callbacks4, &validVersion );
	printf("LOG>generateSaClmHandleT value 2: result: %s\n", SaAisErrorToString(&result) );
	

    
    return values;
}


SaClmHandleT generateValidSaClmHandleT()
{
    int i;
    SaClmHandleT* values = generateSaClmHandleT(&i);

    return values[2];
}

SaClmHandleT** generatePointerSaClmHandleT(int * numberOfGenerated)
{
	static SaClmHandleT** values = NULL;
	
	int number1 = 0; int number2 = 0; int i = 0;
	
	void** genericPointers = generateGenericPointer(&number1);
	SaClmHandleT* typeSpecificValues = generateSaClmHandleT(&number2);
	*numberOfGenerated = number1 + number2;
	
	values = (SaClmHandleT**) malloc( sizeof(SaClmHandleT**) * (*numberOfGenerated) );
	if ( values == NULL )
	{
		perror("Malloc error in generatePointerSaClmHandleT\n");
		exit(1);
	}
	
	for (i = 0; i < number1; i++)
	{
		values[i] = (SaClmHandleT*) genericPointers[i];
	}
	
	for (; i < number1 + number2; i++)
	{
		values[i] = &(typeSpecificValues[ i - number1 ]);
	}
	
	return values;
}

// ------------------------- SaClmNodeAddressFamilyT ---------------------------------
SaClmNodeAddressFamilyT* generateSaClmNodeAddressFamilyT(int * numberOfGenerated)
{
    static SaClmNodeAddressFamilyT values[4];
    *numberOfGenerated = 4;
    
	// 0 - not inicialized
	
	// 1 test value - not valid
	values[1] = 0;

	// 2 test value
	values[2] = SA_CLM_AF_INET;

	// 3 test value
	values[3] = SA_CLM_AF_INET6;


    
    return values;
}




// ------------------------- SaClmNodeAddressT ---------------------------------
SaClmNodeAddressT* generateSaClmNodeAddressT(int * numberOfGenerated)
{
    static SaClmNodeAddressT values[4];
    *numberOfGenerated = 4;
    
	// 0 - not inicialized
	
	// 1 test value - valid value
	values[1].family = SA_CLM_AF_INET;
	values[1].length = 10;
	memcpy( values[1].value, "127.0.0.1", 10 );
	
	// 2 - not initialized structure
	
	// 3 - too long value
	values[3].family = SA_CLM_AF_INET;
	values[3].length = 80;
	memcpy(values[3].value, "192.168.0.192.168.0.192.168.0.192.168.0.192.168.0.192.168.0.192.168.0.192.168.0.", 80);
	

    
    return values;
}




// ------------------------- SaClmNodeIdT ---------------------------------
SaClmNodeIdT* generateSaClmNodeIdT(int * numberOfGenerated)
{
    static SaClmNodeIdT values[14];
    *numberOfGenerated = 14;
    
	// 0 - not inicialized
	
	// 1. test value 
	values[1] = 1;
	
	// 2. test value 
	values[2] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES;
	
	// 3. test value 
	values[3] = -1;
	
	// 4. test value - random
	srand( 5 ); // do not use a changing seed (like time()), because the tests need to be repeatable
	values[4] = rand();
	
	// 5. test value 
	values[5] = SA_TRACK_CURRENT;
	
	// 6. test value 
	values[6] = SA_TRACK_CHANGES;
	
	// 7. test value 
	values[7] = SA_TRACK_CHANGES_ONLY;
	
	// 8. test value 
	values[8] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 9. test value 
	values[9] = SA_TRACK_CHANGES | SA_TRACK_CURRENT;
	
	// 10. test value 
	values[10] = SA_TRACK_CHANGES_ONLY | SA_TRACK_CURRENT;
	
	// 11 test value
	values[11] = pow(2, 8);
	
	// 12 test value
	values[12] = pow(2, 16);
	
	// 13. test value
	values[13] = SA_CLM_LOCAL_NODE_ID;
	

    
    return values;
}




